@@ -23,8 +23,9 @@ use crate::pattern::{Pattern, PatternError, PatternOpts};
 use crate::selector::PathSelector;
 use crate::transform::Transform;
 
-#[derive(Debug, Clone, Copy, clap::ValueEnum)]
+#[derive(Debug, Clone, Copy, clap::ValueEnum, Default)]
 pub enum OutputFormat {
+    #[default]
     Default,
     Fdupes,
     Csv,
@@ -62,12 +63,6 @@ impl FromStr for OutputFormat {
     }
 }
 
-impl Default for OutputFormat {
-    fn default() -> OutputFormat {
-        OutputFormat::Default
-    }
-}
-
 /// Allows to read command line arguments as crate::path::Path.
 #[derive(Clone)]
 pub struct PathParser;
